@@ -68,6 +68,67 @@ class ManageShareTypeAccess(tables.LinkAction):
         return {"project_id": project_id}
 
 
+class MigrationStartAction(tables.LinkAction):
+    name = "migration_start"
+    verbose_name = _("Migrate Share")
+    url = "horizon:admin:shares:migration_start"
+    classes = ("ajax-modal",)
+    policy_rules = (("share", "migration_start"),)
+    ajax = True
+
+    def allowed(self, request, share=None):
+        if share:
+            return (share.status.upper() == "AVAILABLE" and
+                    not getattr(share, 'has_snapshot', False) and
+                    manila.is_migration_enabled())
+        return False
+
+
+class MigrationCompleteAction(tables.LinkAction):
+    name = "migration_complete"
+    verbose_name = _("Complete migration")
+    url = "horizon:admin:shares:migration_complete"
+    classes = ("ajax-modal",)
+    policy_rules = (("share", "migration_complete"),)
+    ajax = True
+
+    def allowed(self, request, share=None):
+        if (share and share.status.upper() == "MIGRATING" and
+                manila.is_migration_enabled()):
+            return True
+        return False
+
+
+class MigrationCancelAction(tables.LinkAction):
+    name = "migration_cancel"
+    verbose_name = _("Cancel migration")
+    url = "horizon:admin:shares:migration_cancel"
+    classes = ("ajax-modal",)
+    policy_rules = (("share", "migration_cancel"),)
+    ajax = True
+
+    def allowed(self, request, share=None):
+        if (share and share.status.upper() == "MIGRATING" and
+                manila.is_migration_enabled()):
+            return True
+        return False
+
+
+class MigrationGetProgressAction(tables.LinkAction):
+    name = "migration_get_progress"
+    verbose_name = _("Get migration progress")
+    url = "horizon:admin:shares:migration_get_progress"
+    classes = ("ajax-modal",)
+    policy_rules = (("share", "migration_get_progress"),)
+    ajax = True
+
+    def allowed(self, request, share=None):
+        if (share and share.status.upper() == "MIGRATING" and
+                manila.is_migration_enabled()):
+            return True
+        return False
+
+
 class ManageShareAction(tables.LinkAction):
     name = "manage"
     verbose_name = _("Manage Share")
@@ -110,7 +171,7 @@ class UpdateShareType(tables.LinkAction):
 
 
 class ShareTypesTable(tables.DataTable):
-    name = tables.Column("name", verbose_name=_("Name"))
+    name = tables.WrappingColumn("name", verbose_name=_("Name"))
     extra_specs = tables.Column("extra_specs", verbose_name=_("Extra specs"), )
     visibility = tables.Column(
         "is_public", verbose_name=_("Visibility"),
@@ -135,10 +196,22 @@ class ShareTypesTable(tables.DataTable):
             DeleteShareType)
 
 
+class ManageReplicas(tables.LinkAction):
+    name = "manage_replicas"
+    verbose_name = _("Manage Replicas")
+    url = "horizon:admin:shares:manage_replicas"
+    classes = ("btn-edit",)
+    policy_rules = (("share", "share:replica_get_all"),)
+
+    def allowed(self, request, share):
+        share_replication_enabled = share.replication_type is not None
+        return manila.is_replication_enabled() and share_replication_enabled
+
+
 class SharesTable(shares_tables.SharesTable):
-    name = tables.Column("name",
-                         verbose_name=_("Name"),
-                         link="horizon:admin:shares:detail")
+    name = tables.WrappingColumn(
+        "name", verbose_name=_("Name"),
+        link="horizon:admin:shares:detail")
     host = tables.Column("host", verbose_name=_("Host"))
     project = tables.Column("project_name", verbose_name=_("Project"))
 
@@ -163,6 +236,11 @@ class SharesTable(shares_tables.SharesTable):
             ManageShareAction,
             shares_tables.DeleteShare)
         row_actions = (
+            ManageReplicas,
+            MigrationStartAction,
+            MigrationCompleteAction,
+            MigrationGetProgressAction,
+            MigrationCancelAction,
             UnmanageShareAction,
             shares_tables.DeleteShare)
         columns = (
@@ -219,9 +297,9 @@ class SnapshotsTable(tables.DataTable):
         ("creating", pgettext_lazy("Current status of snapshot", u"Creating")),
         ("error", pgettext_lazy("Current status of snapshot", u"Error")),
     )
-    name = tables.Column("name",
-                         verbose_name=_("Name"),
-                         link="horizon:admin:shares:snapshot-detail")
+    name = tables.WrappingColumn(
+        "name", verbose_name=_("Name"),
+        link="horizon:admin:shares:snapshot-detail")
     description = tables.Column("description",
                                 verbose_name=_("Description"),
                                 truncate=40)
@@ -282,9 +360,9 @@ class DeleteShareServer(tables.DeleteAction):
 
 
 class SecurityServiceTable(tables.DataTable):
-    name = tables.Column("name",
-                         verbose_name=_("Name"),
-                         link="horizon:admin:shares:security_service_detail")
+    name = tables.WrappingColumn(
+        "name", verbose_name=_("Name"),
+        link="horizon:admin:shares:security_service_detail")
     project = tables.Column("project_name", verbose_name=_("Project"))
     dns_ip = tables.Column("dns_ip", verbose_name=_("DNS IP"))
     server = tables.Column("server", verbose_name=_("Server"))
@@ -316,9 +394,9 @@ class UpdateShareServerRow(tables.Row):
 
 
 class NovaShareNetworkTable(tables.DataTable):
-    name = tables.Column("name",
-                         verbose_name=_("Name"),
-                         link="horizon:admin:shares:share_network_detail")
+    name = tables.WrappingColumn(
+        "name", verbose_name=_("Name"),
+        link="horizon:admin:shares:share_network_detail")
     project = tables.Column("project_name", verbose_name=_("Project"))
     nova_net = tables.Column("nova_net", verbose_name=_("Nova Net"))
     ip_version = tables.Column("ip_version", verbose_name=_("IP Version"))
@@ -345,8 +423,9 @@ class NovaShareNetworkTable(tables.DataTable):
 
 
 class NeutronShareNetworkTable(tables.DataTable):
-    name = tables.Column("name", verbose_name=_("Name"),
-                         link="horizon:project:shares:share_network_detail")
+    name = tables.WrappingColumn(
+        "name", verbose_name=_("Name"),
+        link="horizon:project:shares:share_network_detail")
     project = tables.Column("project_name", verbose_name=_("Project"))
     neutron_net = tables.Column("neutron_net", verbose_name=_("Neutron Net"))
     neutron_subnet = tables.Column(
