@@ -199,17 +199,56 @@ class ManilaApiTests(base.APITestCase):
         mock_reset_state = self.manilaclient.share_replicas.reset_replica_state
         mock_reset_state.assert_called_once_with(replica, state)
 
+    def test_allow_snapshot(self):
+        access_type = "fake_type"
+        access_to = "fake_value"
+
+        api.share_snapshot_allow(self.request, self.id, access_type,
+                                 access_to)
+
+        client = self.manilaclient
+        client.share_snapshots.allow.assert_called_once_with(
+            self.id, access_type, access_to)
+
+    def test_deny_snapshot(self):
+        api.share_snapshot_deny(self.request, self.id, self.id)
+
+        client = self.manilaclient
+        client.share_snapshots.deny.assert_called_once_with(self.id, self.id)
+
+    def test_list_snapshot_rules(self):
+        api.share_snapshot_rules_list(self.request, self.id)
+
+        client = self.manilaclient
+        client.share_snapshots.access_list.assert_called_once_with(self.id)
+
+    def test_list_snapshot_export_locations(self):
+        api.share_snap_export_location_list(self.request, self.id)
+
+        client = self.manilaclient
+        client.share_snapshot_export_locations.list.assert_called_once_with(
+            snapshot=self.id)
+
+    def test_list_snapshot_instance_export_locations(self):
+        api.share_snap_instance_export_location_list(self.request, self.id)
+
+        client = self.manilaclient
+        client.share_snapshot_export_locations.list.assert_called_once_with(
+            snapshot_instance=self.id)
+
     def test_migration_start(self):
         api.migration_start(self.request, 'fake_share', 'fake_host', False,
-                            True, True, False, 'fake_net_id', 'fake_type_id')
+                            True, True, True, True, 'fake_net_id',
+                            'fake_type_id')
 
         self.manilaclient.shares.migration_start.assert_called_once_with(
             'fake_share',
             host='fake_host',
             force_host_assisted_migration=False,
-            nondisruptive=False,
+            nondisruptive=True,
             writable=True,
             preserve_metadata=True,
+            preserve_snapshots=True,
             new_share_network_id='fake_net_id',
             new_share_type_id='fake_type_id'
         )
@@ -236,3 +275,28 @@ class ManilaApiTests(base.APITestCase):
         api.availability_zone_list(self.request)
 
         self.manilaclient.availability_zones.list.assert_called_once_with()
+
+    @ddt.data(
+        {},
+        {"name": "foo_name"},
+        {"description": "foo_desc"},
+        {"neutron_net_id": "foo_neutron_net_id"},
+        {"neutron_subnet_id": "foo_neutron_subnet_id"},
+        {"name": "foo_name", "description": "foo_desc",
+         "neutron_net_id": "foo_neutron_net_id",
+         "neutron_subnet_id": "foo_neutron_subnet_id"},
+    )
+    @ddt.unpack
+    def test_share_network_create(self, **kwargs):
+        expected_kwargs = {
+            "name": None,
+            "description": None,
+            "neutron_net_id": None,
+            "neutron_subnet_id": None,
+        }
+        expected_kwargs.update(kwargs)
+
+        api.share_network_create(self.request, **kwargs)
+
+        mock_sn_create = self.manilaclient.share_networks.create
+        mock_sn_create.assert_called_once_with(**expected_kwargs)
