@@ -132,6 +132,170 @@ class SharesTests(test.BaseAdminViewTests):
             mock.ANY, detailed=True, search_opts={'all_tenants': True})
         self.assertRedirectsNoFollow(res, INDEX_URL)
 
+    @ddt.data(None, Exception('fake'))
+    def test_migration_start_post(self, exc):
+        share = test_data.share
+        url = reverse('horizon:admin:shares:migration_start',
+                      args=[share.id])
+        sn_choices = [test.FakeEntity('sn1_id', 'sn1_name'),
+                      test.FakeEntity('sn2_id', 'sn2_name')]
+
+        st_choices = [test.FakeEntity('st1_id', 'st1_name'),
+                      test.FakeEntity('st2_id', 'st2_name')]
+
+        dest_choices = [
+            test.FakeEntity('ubuntu@beta#BETA', 'ubuntu@beta#BETA'),
+            test.FakeEntity('ubuntu@alpha#ALPHA', 'ubuntu@alpha#ALPHA')
+        ]
+
+        formData = {
+            'share_id': share.id,
+            'name': share.name,
+            'host': 'ubuntu@alpha#ALPHA',
+            'writable': True,
+            'preserve_metadata': True,
+            'preserve_snapshots': True,
+            'force_host_assisted_migration': True,
+            'nondisruptive': True,
+            'new_share_network': 'sn2_id',
+            'new_share_type': 'st2_id',
+        }
+        self.mock_object(
+            api_manila, "share_get", mock.Mock(return_value=share))
+        self.mock_object(
+            api_manila, "migration_start", mock.Mock(side_effect=exc))
+        self.mock_object(
+            api_manila, "share_network_list",
+            mock.Mock(return_value=sn_choices))
+        self.mock_object(
+            api_manila, "share_type_list",
+            mock.Mock(return_value=st_choices))
+        self.mock_object(
+            api_manila, "pool_list",
+            mock.Mock(return_value=dest_choices))
+
+        res = self.client.post(url, formData)
+
+        api_manila.share_get.assert_called_once_with(mock.ANY, share.id)
+        api_manila.migration_start.assert_called_once_with(
+            mock.ANY, formData['share_id'],
+            dest_host=formData['host'],
+            force_host_assisted_migration=(
+                formData['force_host_assisted_migration']),
+            writable=formData['writable'],
+            preserve_metadata=formData['preserve_metadata'],
+            preserve_snapshots=formData['preserve_snapshots'],
+            nondisruptive=formData['nondisruptive'],
+            new_share_network_id=formData['new_share_network'],
+            new_share_type_id=formData['new_share_type'])
+        api_manila.share_network_list.assert_called_once_with(mock.ANY)
+        api_manila.share_type_list.assert_called_once_with(mock.ANY)
+        api_manila.pool_list.assert_called_once_with(mock.ANY)
+        self.assertEqual(302, res.status_code)
+        self.assertTemplateNotUsed(res, 'admin/shares/migration_start.html')
+        self.assertRedirectsNoFollow(res, INDEX_URL)
+
+    @ddt.data('migration_start', 'migration_cancel', 'migration_complete',
+              'migration_get_progress')
+    def test_migration_forms_open_form_successfully(self, method):
+        share = test_data.share
+        url = reverse('horizon:admin:shares:' + method, args=[share.id])
+
+        self.mock_object(
+            api_manila, "share_get", mock.Mock(return_value=share))
+        self.mock_object(api_manila, method)
+
+        if method == 'migration_start':
+            self.mock_object(
+                api_manila, "share_network_list",
+                mock.Mock(
+                    return_value=[test.FakeEntity('sn1_id', 'sn1_name'),
+                                  test.FakeEntity('sn2_id', 'sn2_name')]))
+
+            self.mock_object(
+                api_manila, "share_type_list",
+                mock.Mock(
+                    return_value=[test.FakeEntity('st1_id', 'st1_name'),
+                                  test.FakeEntity('st2_id', 'st2_name')]))
+
+            self.mock_object(
+                api_manila, "pool_list",
+                mock.Mock(return_value=[test.FakeEntity('ubuntu@beta#BETA',
+                                                        'ubuntu@beta#BETA'),
+                                        test.FakeEntity('ubuntu@alpha#ALPHA',
+                                                        'ubuntu@alpha#ALPHA')
+                                        ]))
+
+        res = self.client.get(url)
+
+        api_manila.share_get.assert_called_once_with(mock.ANY, share.id)
+
+        self.assertFalse(getattr(api_manila, method).called)
+
+        self.assertEqual(res.status_code, 200)
+        self.assertTemplateUsed(res, 'admin/shares/' + method + '.html')
+
+        if method == 'migration_start':
+            api_manila.share_network_list.assert_called_once_with(mock.ANY)
+            api_manila.share_type_list.assert_called_once_with(mock.ANY)
+            api_manila.pool_list.assert_called_once_with(mock.ANY)
+
+    @ddt.data('migration_start', 'migration_cancel', 'migration_complete',
+              'migration_get_progress')
+    def test_migration_start_get_share_exception(self, method):
+        share = test_data.share
+        url = reverse('horizon:admin:shares:' + method, args=[share.id])
+
+        self.mock_object(
+            api_manila, "share_get", mock.Mock(side_effect=Exception('fake')))
+        self.mock_object(api_manila, method)
+
+        res = self.client.get(url)
+
+        api_manila.share_get.assert_called_once_with(mock.ANY, share.id)
+        self.assertFalse(getattr(api_manila, method).called)
+
+        self.assertEqual(res.status_code, 302)
+        self.assertTemplateNotUsed(res, 'admin/shares/' + method + '.html')
+
+    @ddt.data({'method': 'migration_complete', 'exc': None},
+              {'method': 'migration_complete', 'exc': Exception('fake')},
+              {'method': 'migration_cancel', 'exc': None},
+              {'method': 'migration_cancel', 'exc': Exception('fake')},
+              {'method': 'migration_get_progress',
+               'exc': {'response': 200, 'total_progress': 25}},
+              {'method': 'migration_get_progress', 'exc': Exception('fake')})
+    @ddt.unpack
+    def test_migration_forms_post(self, exc, method):
+        share = test_data.share
+        url = reverse('horizon:admin:shares:' + method,
+                      args=[share.id])
+        formData = {
+            'share_id': share.id,
+            'name': share.name,
+        }
+
+        self.mock_object(
+            api_manila, "share_get", mock.Mock(return_value=share))
+        self.mock_object(api_manila, method, mock.Mock(
+            side_effect=exc))
+
+        res = self.client.post(url, formData)
+
+        api_manila.share_get.assert_called_once_with(mock.ANY, share.id)
+        getattr(api_manila, method).assert_called_once_with(
+            mock.ANY, formData['share_id'])
+
+        status_code = 200 if exc else 302
+        self.assertEqual(res.status_code, status_code)
+        if not exc:
+            self.assertTemplateNotUsed(
+                res, 'admin/shares/' + method + '.html')
+            self.assertRedirectsNoFollow(res, INDEX_URL)
+        else:
+            self.assertTemplateUsed(
+                res, 'admin/shares/' + method + '.html')
+
 
 class ShareInstanceTests(test.BaseAdminViewTests):
 
@@ -144,8 +308,6 @@ class ShareInstanceTests(test.BaseAdminViewTests):
         self.mock_object(
             api_manila, "share_instance_list",
             mock.Mock(return_value=share_instances))
-        self.mock_object(
-            api_neutron, "is_service_enabled", mock.Mock(return_value=[True]))
         self.mock_object(
             api_keystone, "tenant_list", mock.Mock(return_value=([], None)))
 
@@ -177,7 +339,6 @@ class ShareInstanceTests(test.BaseAdminViewTests):
                 1, 200)
         api_manila.share_instance_list.assert_called_once_with(mock.ANY)
         self.assertEqual(5, api_keystone.tenant_list.call_count)
-        self.assertEqual(3, api_neutron.is_service_enabled.call_count)
 
     def test_detail_view_share_instance(self):
         share_instance = test_data.share_instance
@@ -191,8 +352,6 @@ class ShareInstanceTests(test.BaseAdminViewTests):
         self.mock_object(
             api_manila, "share_instance_export_location_list",
             mock.Mock(return_value=test_data.export_locations))
-        self.mock_object(
-            api_neutron, "is_service_enabled", mock.Mock(return_value=[True]))
 
         res = self.client.get(url)
 
@@ -225,7 +384,6 @@ class ShareInstanceTests(test.BaseAdminViewTests):
             mock.ANY, share_instance.id)
         api_manila.share_instance_export_location_list.assert_called_once_with(
             mock.ANY, share_instance.id)
-        self.assertEqual(3, api_neutron.is_service_enabled.call_count)
 
     def test_detail_view_share_instance_with_exception(self):
         share_instance = test_data.share_instance
@@ -263,8 +421,6 @@ class ShareServerTests(test.BaseAdminViewTests):
             api_manila, "share_list",
             mock.Mock(side_effect=[
                 [], [test_data.share], [test_data.nameless_share]]))
-        self.mock_object(
-            api_neutron, "is_service_enabled", mock.Mock(return_value=[True]))
         self.mock_object(
             api_keystone, "tenant_list",
             mock.Mock(return_value=(projects, None)))
@@ -294,7 +450,6 @@ class ShareServerTests(test.BaseAdminViewTests):
         ])
         api_manila.share_server_list.assert_called_once_with(mock.ANY)
         self.assertEqual(1, api_keystone.tenant_list.call_count)
-        self.assertEqual(3, api_neutron.is_service_enabled.call_count)
 
     def test_detail_view_share_server(self):
         share_server = test_data.share_server
@@ -306,8 +461,6 @@ class ShareServerTests(test.BaseAdminViewTests):
             mock.Mock(return_value=share_server))
         self.mock_object(
             api_manila, "share_list", mock.Mock(return_value=shares))
-        self.mock_object(
-            api_neutron, "is_service_enabled", mock.Mock(return_value=[True]))
 
         res = self.client.get(url)
 
@@ -341,7 +494,6 @@ class ShareServerTests(test.BaseAdminViewTests):
             mock.ANY, share_server.id)
         api_manila.share_list.assert_called_once_with(
             mock.ANY, search_opts={"share_server_id": share_server.id})
-        self.assertEqual(3, api_neutron.is_service_enabled.call_count)
 
     def test_detail_view_share_server_with_exception(self):
         share_server = test_data.share_server
@@ -373,8 +525,6 @@ class SecurityServicesTests(test.BaseAdminViewTests):
         self.mock_object(
             api_manila, "security_service_get",
             mock.Mock(return_value=sec_service))
-        self.mock_object(
-            api_neutron, "is_service_enabled", mock.Mock(return_value=[True]))
         url = reverse('horizon:admin:shares:security_service_detail',
                       args=[sec_service.id])
 
@@ -392,7 +542,6 @@ class SecurityServicesTests(test.BaseAdminViewTests):
         self.assertNoMessages()
         api_manila.security_service_get.assert_called_once_with(
             mock.ANY, sec_service.id)
-        self.assertEqual(3, api_neutron.is_service_enabled.call_count)
 
     def test_detail_view_with_exception(self):
         url = reverse('horizon:admin:shares:security_service_detail',
@@ -456,8 +605,6 @@ class ShareNetworksTests(test.BaseAdminViewTests):
             api_neutron, "subnet_get", mock.Mock(return_value=subnet))
         url = reverse('horizon:project:shares:share_network_detail',
                       args=[share_net.id])
-        self.mock_object(
-            api_neutron, "is_service_enabled", mock.Mock(return_value=[True]))
 
         res = self.client.get(url)
 
@@ -482,7 +629,6 @@ class ShareNetworksTests(test.BaseAdminViewTests):
             mock.ANY, share_net.neutron_net_id)
         api_neutron.subnet_get.assert_called_once_with(
             mock.ANY, share_net.neutron_subnet_id)
-        self.assertEqual(3, api_neutron.is_service_enabled.call_count)
 
     def test_detail_view_network_not_found(self):
         share_net = test_data.active_share_network
@@ -496,8 +642,6 @@ class ShareNetworksTests(test.BaseAdminViewTests):
         self.mock_object(
             api_manila, "share_network_security_service_list",
             mock.Mock(return_value=[sec_service]))
-        self.mock_object(
-            api_neutron, "is_service_enabled", mock.Mock(return_value=[True]))
         self.mock_object(
             api_neutron, "network_get", mock.Mock(
                 side_effect=exceptions.NeutronClientException('fake', 500)))
@@ -530,7 +674,6 @@ class ShareNetworksTests(test.BaseAdminViewTests):
             mock.ANY, share_net.neutron_net_id)
         api_neutron.subnet_get.assert_called_once_with(
             mock.ANY, share_net.neutron_subnet_id)
-        self.assertEqual(3, api_neutron.is_service_enabled.call_count)
 
     def test_detail_view_with_exception(self):
         url = reverse('horizon:admin:shares:share_network_detail',
@@ -590,8 +733,6 @@ class SnapshotsTests(test.BaseAdminViewTests):
             api_manila, "share_snapshot_get", mock.Mock(return_value=snapshot))
         self.mock_object(
             api_manila, "share_get", mock.Mock(return_value=share))
-        self.mock_object(
-            api_neutron, "is_service_enabled", mock.Mock(return_value=[True]))
 
         res = self.client.get(url)
 
@@ -608,7 +749,59 @@ class SnapshotsTests(test.BaseAdminViewTests):
         api_manila.share_get.assert_called_once_with(mock.ANY, share.id)
         api_manila.share_snapshot_get.assert_called_once_with(
             mock.ANY, snapshot.id)
-        self.assertEqual(3, api_neutron.is_service_enabled.call_count)
+
+    def test_detail_view_with_mount_support(self):
+        snapshot = test_data.snapshot_mount_support
+        rules = [test_data.ip_rule, test_data.user_rule, test_data.cephx_rule]
+        export_locations = test_data.admin_snapshot_export_locations
+        share = test_data.share_mount_snapshot
+        url = reverse('horizon:project:shares:snapshot-detail',
+                      args=[snapshot.id])
+        self.mock_object(
+            api_manila, "share_snapshot_get", mock.Mock(return_value=snapshot))
+        self.mock_object(
+            api_manila, "share_snapshot_rules_list", mock.Mock(
+                return_value=rules))
+        self.mock_object(
+            api_manila, "share_snap_export_location_list", mock.Mock(
+                return_value=export_locations))
+        self.mock_object(
+            api_manila, "share_get", mock.Mock(return_value=share))
+
+        res = self.client.get(url)
+
+        self.assertContains(res, "<h1>Snapshot Details: %s</h1>"
+                                 % snapshot.name,
+                            1, 200)
+        self.assertContains(res, "<dd>%s</dd>" % snapshot.name, 1, 200)
+        self.assertContains(res, "<dd>%s</dd>" % snapshot.id, 1, 200)
+        self.assertContains(res,
+                            "<dd><a href=\"/admin/shares/%s/\">%s</a></dd>" %
+                            (snapshot.share_id, share.name), 1, 200)
+        self.assertContains(res, "<dd>%s GiB</dd>" % snapshot.size, 1, 200)
+        for el in export_locations:
+            self.assertContains(res, "value=\"%s\"" % el.path, 1, 200)
+            self.assertContains(
+                res, "<div><b>Is admin only:</b> %s</div>" % el.is_admin_only,
+                1, 200)
+            self.assertContains(
+                res, ("<div><b>Snapshot Replica ID:</b> %s</div>" %
+                      el.share_snapshot_instance_id), 1, 200)
+        for rule in rules:
+            self.assertContains(res, "<dt>%s</dt>" % rule.access_type, 1, 200)
+            self.assertContains(
+                res, "<div><b>Access to: </b>%s</div>" % rule.access_to,
+                1, 200)
+        self.assertContains(
+            res, "<div><b>Status: </b>active</div>", len(rules), 200)
+        self.assertNoMessages()
+        api_manila.share_get.assert_called_once_with(mock.ANY, share.id)
+        api_manila.share_snapshot_get.assert_called_once_with(
+            mock.ANY, snapshot.id)
+        api_manila.share_snapshot_rules_list.assert_called_once_with(
+            mock.ANY, snapshot.id)
+        api_manila.share_snap_export_location_list.assert_called_once_with(
+            mock.ANY, snapshot)
 
     def test_detail_view_with_exception(self):
         url = reverse('horizon:admin:shares:snapshot-detail',
